@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2004, 2017 IBM Corporation and others.
+ * Copyright (c) 2004, 2018 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -42,8 +42,6 @@ import org.eclipse.osgi.container.ModuleWire;
 import org.eclipse.osgi.container.ModuleWiring;
 import org.eclipse.osgi.container.builders.OSGiManifestBuilderFactory;
 import org.eclipse.osgi.container.namespaces.EquinoxModuleDataNamespace;
-import org.eclipse.osgi.framework.util.KeyedElement;
-import org.eclipse.osgi.framework.util.KeyedHashSet;
 import org.eclipse.osgi.internal.debug.Debug;
 import org.eclipse.osgi.internal.framework.EquinoxConfiguration;
 import org.eclipse.osgi.internal.framework.EquinoxContainer;
@@ -59,6 +57,7 @@ import org.osgi.framework.Bundle;
 import org.osgi.framework.BundleContext;
 import org.osgi.framework.BundleException;
 import org.osgi.framework.Constants;
+import org.osgi.framework.FrameworkEvent;
 import org.osgi.framework.namespace.BundleNamespace;
 import org.osgi.framework.namespace.HostNamespace;
 import org.osgi.framework.namespace.PackageNamespace;
@@ -76,6 +75,7 @@ public class BundleLoader extends ModuleLoader {
 	public final static String JAVA_PACKAGE = "java."; //$NON-NLS-1$
 
 	public final static ClassContext CLASS_CONTEXT = AccessController.doPrivileged(new PrivilegedAction<ClassContext>() {
+		@Override
 		public ClassContext run() {
 			return new ClassContext();
 		}
@@ -105,9 +105,9 @@ public class BundleLoader extends ModuleLoader {
 	private final BundleLoaderSources exportSources;
 
 	/* cache of required package sources. Key is packagename, value is PackageSource */
-	private final KeyedHashSet requiredSources = new KeyedHashSet(false);
+	private final Map<String, PackageSource> requiredSources = new HashMap<>();
 	/* cache of imported packages. Key is packagename, Value is PackageSource */
-	private final KeyedHashSet importedSources = new KeyedHashSet(false);
+	private final Map<String, PackageSource> importedSources = new HashMap<>();
 	private final List<ModuleWire> requiredBundleWires;
 
 	/* @GuardedBy("importedSources") */
@@ -127,6 +127,7 @@ public class BundleLoader extends ModuleLoader {
 	private volatile ModuleClassLoader classloader;
 	private final ClassLoader parent;
 	private final AtomicBoolean triggerClassLoaded = new AtomicBoolean(false);
+	private final AtomicBoolean firstUseOfInvalidLoader = new AtomicBoolean(false);
 
 	/**
 	 * Returns the package name from the specified class name.
@@ -223,7 +224,7 @@ public class BundleLoader extends ModuleLoader {
 
 	final PackageSource createExportPackageSource(ModuleWire importWire, Collection<BundleLoader> visited) {
 		String name = (String) importWire.getCapability().getAttributes().get(PackageNamespace.PACKAGE_NAMESPACE);
-		BundleLoader providerLoader = (BundleLoader) importWire.getProviderWiring().getModuleLoader();
+		BundleLoader providerLoader = getProviderLoader(importWire);
 		if (providerLoader == null) {
 			return createMultiSource(name, new PackageSource[0]);
 		}
@@ -238,11 +239,13 @@ public class BundleLoader extends ModuleLoader {
 		if (sources.length == 1)
 			return sources[0];
 		List<SingleSourcePackage> sourceList = new ArrayList<>(sources.length);
-		for (int i = 0; i < sources.length; i++) {
-			SingleSourcePackage[] innerSources = sources[i].getSuppliers();
-			for (int j = 0; j < innerSources.length; j++)
-				if (!sourceList.contains(innerSources[j]))
-					sourceList.add(innerSources[j]);
+		for (PackageSource source : sources) {
+			SingleSourcePackage[] innerSources = source.getSuppliers();
+			for (SingleSourcePackage innerSource : innerSources) {
+				if (!sourceList.contains(innerSource)) {
+					sourceList.add(innerSource);
+				}
+			}
 		}
 		return new MultiSourcePackage(packageName, sourceList.toArray(new SingleSourcePackage[sourceList.size()]));
 	}
@@ -590,6 +593,7 @@ public class BundleLoader extends ModuleLoader {
 		if (System.getSecurityManager() == null)
 			return clazz.getClassLoader();
 		return AccessController.doPrivileged(new PrivilegedAction<ClassLoader>() {
+			@Override
 			public ClassLoader run() {
 				return clazz.getClassLoader();
 			}
@@ -784,13 +788,13 @@ public class BundleLoader extends ModuleLoader {
 		boolean subPackages = (options & BundleWiring.LISTRESOURCES_RECURSE) != 0;
 		List<String> packages = new ArrayList<>();
 		// search imported package names
-		KeyedHashSet importSources = getImportedSources(null);
-		KeyedElement[] imports;
+		Map<String, PackageSource> importSources = getImportedSources(null);
+		Collection<PackageSource> imports;
 		synchronized (importSources) {
-			imports = importSources.elements();
+			imports = new ArrayList<>(importSources.values());
 		}
-		for (KeyedElement keyedElement : imports) {
-			String id = ((PackageSource) keyedElement).getId();
+		for (PackageSource source : imports) {
+			String id = source.getId();
 			if (id.equals(pkgName) || (subPackages && isSubPackage(pkgName, id)))
 				packages.add(id);
 		}
@@ -799,7 +803,7 @@ public class BundleLoader extends ModuleLoader {
 		Collection<BundleLoader> visited = new ArrayList<>();
 		visited.add(this); // always add ourselves so we do not recurse back to ourselves
 		for (ModuleWire bundleWire : requiredBundleWires) {
-			BundleLoader loader = (BundleLoader) bundleWire.getProviderWiring().getModuleLoader();
+			BundleLoader loader = getProviderLoader(bundleWire);
 			if (loader != null) {
 				loader.addProvidedPackageNames(pkgName, packages, subPackages, visited);
 			}
@@ -891,6 +895,7 @@ public class BundleLoader extends ModuleLoader {
 	 * Return a string representation of this loader.
 	 * @return String
 	 */
+	@Override
 	public final String toString() {
 		ModuleRevision revision = wiring.getRevision();
 		String name = revision.getSymbolicName();
@@ -920,15 +925,19 @@ public class BundleLoader extends ModuleLoader {
 
 			/* match against specific names */
 			if (dynamicImportPackages != null)
-				for (int i = 0; i < dynamicImportPackages.length; i++)
-					if (pkgname.equals(dynamicImportPackages[i]))
+				for (String dynamicImportPackage : dynamicImportPackages) {
+					if (pkgname.equals(dynamicImportPackage)) {
 						return true;
+					}
+				}
 
 			/* match against names with trailing wildcards */
 			if (dynamicImportPackageStems != null)
-				for (int i = 0; i < dynamicImportPackageStems.length; i++)
-					if (pkgname.startsWith(dynamicImportPackageStems[i]))
+				for (String dynamicImportPackageStem : dynamicImportPackageStems) {
+					if (pkgname.startsWith(dynamicImportPackageStem)) {
 						return true;
+					}
+				}
 		}
 		return false;
 	}
@@ -951,7 +960,7 @@ public class BundleLoader extends ModuleLoader {
 				// always add required bundles first if we locally provide the package
 				// This allows a bundle to provide a package from a required bundle without 
 				// re-exporting the whole required bundle.
-				BundleLoader loader = (BundleLoader) bundleWire.getProviderWiring().getModuleLoader();
+				BundleLoader loader = getProviderLoader(bundleWire);
 				if (loader != null) {
 					loader.addExportedProvidersFor(packageName, result, visited);
 				}
@@ -962,6 +971,19 @@ public class BundleLoader extends ModuleLoader {
 			result.add(local);
 	}
 
+	private BundleLoader getProviderLoader(ModuleWire wire) {
+		ModuleWiring provider = wire.getProviderWiring();
+		if (provider == null) {
+			if (firstUseOfInvalidLoader.getAndSet(true)) {
+				// publish a framework event once per loader, include an exception to show the stack
+				String message = "Invalid class loader from a refreshed bundle is being used: " + toString(); //$NON-NLS-1$
+				container.getEventPublisher().publishFrameworkEvent(FrameworkEvent.ERROR, wiring.getBundle(), new IllegalStateException(message));
+			}
+			return null;
+		}
+		return (BundleLoader) provider.getModuleLoader();
+	}
+
 	final void addProvidedPackageNames(String packageName, List<String> result, boolean subPackages, Collection<BundleLoader> visited) {
 		if (visited.contains(this))
 			return;
@@ -982,7 +1004,7 @@ public class BundleLoader extends ModuleLoader {
 		}
 		for (ModuleWire bundleWire : requiredBundleWires) {
 			if (BundleNamespace.VISIBILITY_REEXPORT.equals(bundleWire.getRequirement().getDirectives().get(BundleNamespace.REQUIREMENT_VISIBILITY_DIRECTIVE))) {
-				BundleLoader loader = (BundleLoader) bundleWire.getProviderWiring().getModuleLoader();
+				BundleLoader loader = getProviderLoader(bundleWire);
 				if (loader != null) {
 					loader.addProvidedPackageNames(packageName, result, subPackages, visited);
 				}
@@ -1036,8 +1058,8 @@ public class BundleLoader extends ModuleLoader {
 				stems = new ArrayList<>(size);
 			} else {
 				stems = new ArrayList<>(size + dynamicImportPackageStems.length);
-				for (int i = 0; i < dynamicImportPackageStems.length; i++) {
-					stems.add(dynamicImportPackageStems[i]);
+				for (String dynamicImportPackageStem : dynamicImportPackageStems) {
+					stems.add(dynamicImportPackageStem);
 				}
 			}
 
@@ -1046,8 +1068,8 @@ public class BundleLoader extends ModuleLoader {
 				names = new ArrayList<>(size);
 			} else {
 				names = new ArrayList<>(size + dynamicImportPackages.length);
-				for (int i = 0; i < dynamicImportPackages.length; i++) {
-					names.add(dynamicImportPackages[i]);
+				for (String dynamicImportPackage : dynamicImportPackages) {
+					names.add(dynamicImportPackage);
 				}
 			}
 
@@ -1090,8 +1112,7 @@ public class BundleLoader extends ModuleLoader {
 		StringBuilder importSpec = new StringBuilder();
 		for (ManifestElement dynamicImportElement : packages) {
 			String[] names = dynamicImportElement.getValueComponents();
-			for (String name : names)
-				dynamicImports.add(name);
+			Collections.addAll(dynamicImports, names);
 			if (importSpec.length() > 0) {
 				importSpec.append(',');
 			}
@@ -1129,13 +1150,13 @@ public class BundleLoader extends ModuleLoader {
 	}
 
 	private PackageSource findImportedSource(String pkgName, Collection<BundleLoader> visited) {
-		KeyedHashSet imports = getImportedSources(visited);
+		Map<String, PackageSource> imports = getImportedSources(visited);
 		synchronized (imports) {
-			return (PackageSource) imports.getByKey(pkgName);
+			return imports.get(pkgName);
 		}
 	}
 
-	private KeyedHashSet getImportedSources(Collection<BundleLoader> visited) {
+	private Map<String, PackageSource> getImportedSources(Collection<BundleLoader> visited) {
 		synchronized (importedSources) {
 			if (importsInitialized) {
 				return importedSources;
@@ -1145,7 +1166,7 @@ public class BundleLoader extends ModuleLoader {
 				for (ModuleWire importWire : importWires) {
 					PackageSource source = createExportPackageSource(importWire, visited);
 					if (source != null) {
-						importedSources.add(source);
+						importedSources.put(source.getId(), source);
 					}
 				}
 			}
@@ -1167,7 +1188,7 @@ public class BundleLoader extends ModuleLoader {
 					Debug.println("BundleLoader[" + this + "] using dynamic import source: " + source); //$NON-NLS-1$ //$NON-NLS-2$
 				}
 				synchronized (importedSources) {
-					importedSources.add(source);
+					importedSources.put(source.getId(), source);
 				}
 				return source;
 			}
@@ -1176,8 +1197,11 @@ public class BundleLoader extends ModuleLoader {
 	}
 
 	private PackageSource findRequiredSource(String pkgName, Collection<BundleLoader> visited) {
+		if (requiredBundleWires.isEmpty()) {
+			return null;
+		}
 		synchronized (requiredSources) {
-			PackageSource result = (PackageSource) requiredSources.getByKey(pkgName);
+			PackageSource result = requiredSources.get(pkgName);
 			if (result != null)
 				return result.isNullSource() ? null : result;
 		}
@@ -1187,7 +1211,7 @@ public class BundleLoader extends ModuleLoader {
 			visited.add(this); // always add ourselves so we do not recurse back to ourselves
 		List<PackageSource> result = new ArrayList<>(3);
 		for (ModuleWire bundleWire : requiredBundleWires) {
-			BundleLoader loader = (BundleLoader) bundleWire.getProviderWiring().getModuleLoader();
+			BundleLoader loader = getProviderLoader(bundleWire);
 			if (loader != null) {
 				loader.addExportedProvidersFor(pkgName, result, visited);
 			}
@@ -1207,7 +1231,7 @@ public class BundleLoader extends ModuleLoader {
 			source = createMultiSource(pkgName, srcs);
 		}
 		synchronized (requiredSources) {
-			requiredSources.add(source);
+			requiredSources.put(source.getId(), source);
 		}
 		return source.isNullSource() ? null : source;
 	}
@@ -1232,6 +1256,7 @@ public class BundleLoader extends ModuleLoader {
 
 	static final class ClassContext extends SecurityManager {
 		// need to make this method public
+		@Override
 		public Class<?>[] getClassContext() {
 			return super.getClassContext();
 		}
