@@ -25,6 +25,7 @@ import java.util.Collections;
 import java.util.Enumeration;
 import java.util.List;
 import java.util.ListIterator;
+import java.util.NoSuchElementException;
 import org.eclipse.osgi.container.Module;
 import org.eclipse.osgi.container.ModuleCapability;
 import org.eclipse.osgi.container.ModuleContainerAdaptor.ContainerEvent;
@@ -145,25 +146,27 @@ public class ClasspathManager {
 	 *
 	 */
 	public void close() {
-		for (int i = 0; i < entries.length; i++) {
-			if (entries[i] != null) {
+		for (ClasspathEntry entry : entries) {
+			if (entry != null) {
 				try {
-					entries[i].close();
-				} catch (IOException e) {
+					entry.close();
+				}catch (IOException e) {
 					generation.getBundleInfo().getStorage().getAdaptor().publishContainerEvent(ContainerEvent.ERROR, generation.getRevision().getRevisions().getModule(), e);
 				}
 			}
 		}
 		FragmentClasspath[] currentFragments = getFragmentClasspaths();
-		for (int i = 0; i < currentFragments.length; i++)
-			currentFragments[i].close();
+		for (FragmentClasspath currentFragment : currentFragments) {
+			currentFragment.close();
+		}
 	}
 
 	private ClasspathEntry[] buildClasspath(String[] cp, ClasspathManager hostloader, Generation source) {
 		ArrayList<ClasspathEntry> result = new ArrayList<>(cp.length);
 		// add the regular classpath entries.
-		for (int i = 0; i < cp.length; i++)
-			findClassPathEntry(result, cp[i], hostloader, source);
+		for (String cpEntry : cp) {
+			findClassPathEntry(result, cpEntry, hostloader, source);
+		}
 		return result.toArray(new ClasspathEntry[result.size()]);
 	}
 
@@ -218,8 +221,7 @@ public class ClasspathManager {
 		// only check for fragments if the generation is the host's generation.
 		if (hostManager.generation == generation) {
 			FragmentClasspath[] hostFrags = hostManager.getFragmentClasspaths();
-			for (int i = 0; i < hostFrags.length; i++) {
-				FragmentClasspath fragCP = hostFrags[i];
+			for (FragmentClasspath fragCP : hostFrags) {
 				element = hostManager.getClasspath(cp, fragCP.getGeneration());
 				if (element != null) {
 					result.add(element);
@@ -357,18 +359,30 @@ public class ClasspathManager {
 	 */
 	public URL findLocalResource(String resource) {
 		List<ClassLoaderHook> hooks = hookRegistry.getClassLoaderHooks();
+		boolean hookFailed = false;
 		for (ClassLoaderHook hook : hooks) {
-			hook.preFindLocalResource(resource, this);
+			try {
+				hook.preFindLocalResource(resource, this);
+			} catch (NoSuchElementException e) {
+				// mark the resource load as failed, but continue to all the hooks
+				hookFailed = true;
+			}
 		}
 		URL result = null;
 		try {
-			result = findLocalResourceImpl(resource, -1);
-			return result;
+			if (!hookFailed) {
+				result = findLocalResourceImpl(resource, -1);
+			}
 		} finally {
 			for (ClassLoaderHook hook : hooks) {
-				hook.postFindLocalResource(resource, result, this);
+				try {
+					hook.postFindLocalResource(resource, result, this);
+				} catch (NoSuchElementException e) {
+					result = null;
+				}
 			}
 		}
+		return result;
 	}
 
 	private URL findLocalResourceImpl(String resource, int classPathIndex) {
@@ -431,7 +445,7 @@ public class ClasspathManager {
 			ClasspathEntry[] hookEntries = hook.getClassPathEntries(resource, this);
 			if (hookEntries != null) {
 				findLocalResources(resource, hookEntries, m, classPathIndex, resources);
-				return resources.size() > 0 ? Collections.enumeration(resources): EMPTY_ENUMERATION;
+				return resources.size() > 0 ? Collections.enumeration(resources) : EMPTY_ENUMERATION;
 			}
 		}
 
